{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Zig.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/zig.xml and 'make bootstrap'.
module Skylighting.Syntax.Zig (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Zig.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azig.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1builtin_functions\NUL\NUL\NUL\NUL\NUL\NUL\NULn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@addrSpaceCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@addWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@alignCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@alignOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX@as\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@atomicLoad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@atomicRmw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@atomicStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@bitCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@bitOffsetOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@boolToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@bitSizeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@breakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@mulAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@byteSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@bitReverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@offsetOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@cDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@cImport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@cInclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@clz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@cmpxchgStrong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@cmpxchgWeak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@compileError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@compileLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@ctz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@cUndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@cVaArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@cVaCopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@cVaEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@cVaStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@divExact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@divFloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@divTrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@embedFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@enumToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@errorName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1@errorReturnTrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@errorToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@errSetCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@export\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@fence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@field\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI@fieldParentPtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@floatCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@floatToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@frameAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@hasDecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@hasField\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@import\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@intCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@intToEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@intToError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@intToFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@intToPtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@max\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@memcpy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@memset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@min\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI@wasmMemorySize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI@wasmMemoryGrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@mulWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@panic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@popCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@prefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@ptrCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@ptrToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@rem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@returnAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@select\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@setAlignStack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@setCold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3@setEvalBranchQuota\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@setFloatMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1@setRuntimeSafety\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@shlExact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@shlWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@shrExact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@shuffle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@sizeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@splat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@reduce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@src\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@sqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@sin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@cos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@tan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@exp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@exp2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@log\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@log2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@log10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@fabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@floor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@ceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@trunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@round\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@subWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@tagName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@This\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@truncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@Type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@typeInfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@typeName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@TypeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@unionInit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@Vector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdefer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\berrdefer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\taddrspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\banyframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcallconv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnosuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopaque\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKorelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpacked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlinksection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunreachable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOusingnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bliterals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tundefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmodifiers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQawait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vthreadlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tallowzero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomptime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXi8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXu8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTi128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTu128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bc_ushort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQc_int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_uint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_long\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_ulong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nc_longlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vc_ulonglong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fc_longdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf80\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tanyopaque\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\banyerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcomptime_int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcomptime_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL/\\\\([nrt'\"\\\\]|x[0-9a-fA-F]{2}|u\\{[0-9a-fA-F]+\\})\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\\\\(x[0-9a-fA-F]?|u\\{[0-9a-fA-F]{0,8}\\}?)?\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiline String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiline String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1!%&*+,-./:<=>?^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleQuoteString\SOH\\\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiline String\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\taddrspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\banyframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcallconv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlinksection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnosuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopaque\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKorelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpacked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunreachable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOusingnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\NUL\NUL\NUL\NUL\NUL\NUL\NUL\banyerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tanyopaque\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQc_int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_long\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fc_longdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nc_longlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_uint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_ulong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vc_ulonglong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bc_ushort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcomptime_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcomptime_int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf80\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTi128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXi8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTu128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXu8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tundefined\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@This\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@Type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@TypeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@Vector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@addWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@addrSpaceCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@alignCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@alignOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX@as\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@atomicLoad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@atomicRmw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@atomicStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@bitCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@bitOffsetOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@bitReverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@bitSizeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@boolToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@breakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@byteSwap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@cDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@cImport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@cInclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@cUndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@cVaArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@cVaCopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@cVaEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@cVaStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@ceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@clz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@cmpxchgStrong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@cmpxchgWeak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@compileError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@compileLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@cos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@ctz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@divExact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@divFloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@divTrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@embedFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@enumToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@errSetCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@errorName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1@errorReturnTrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@errorToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@exp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@exp2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@export\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@fabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@fence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@field\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI@fieldParentPtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@floatCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@floatToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@floor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@frameAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@hasDecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@hasField\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@import\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@intCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@intToEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@intToError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@intToFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@intToPtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@log\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@log10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@log2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@max\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@memcpy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@memset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@min\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@mulAdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@mulWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@offsetOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@panic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@popCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@prefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@ptrCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@ptrToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@reduce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@rem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@returnAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@round\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@select\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@setAlignStack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@setCold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3@setEvalBranchQuota\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@setFloatMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1@setRuntimeSafety\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@shlExact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@shlWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@shrExact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@shuffle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@sin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@sizeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@splat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@sqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@src\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE@subWithOverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@tagName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@tan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@trunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@truncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@typeInfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@typeName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@unionInit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI@wasmMemoryGrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI@wasmMemorySize\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdefer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\berrdefer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tallowzero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQawait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomptime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vthreadlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULx(?:[0-9]+(?:_[0-9]+)*)(\\.(?:[0-9]+(?:_[0-9]+)*)(?:[eE][+-]?(?:[0-9]+(?:_[0-9]+)*))?|(?:[eE][+-]?(?:[0-9]+(?:_[0-9]+)*)))\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL/0(?=[^xob]|$)|(?=0[xob])|(?:[0-9]+(?:_[0-9]+)*)\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\146\&0x(?:[0-9A-Fa-f]+(?:_[0-9A-Fa-f]+)*)(\\.(?:[0-9A-Fa-f]+(?:_[0-9A-Fa-f]+)*)(?:[pP][-+]?(?:[0-9]+(?:_[0-9]+)*))?|(?:[pP][-+]?(?:[0-9]+(?:_[0-9]+)*)))\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$0x(?:[0-9A-Fa-f]+(?:_[0-9A-Fa-f]+)*)\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN0o(?:[0-7]+(?:_[0-7]+)*)\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN0b(?:[01]+(?:_[01]+)*)\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\NUL0\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.0123456789\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!Waqar Ahmed (waqar.17a@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.zig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
